@@ -16,9 +16,11 @@ from .base import (
     ChargePointSettings,
     ChargePointStatus,
     ChargingSession,
+    StartAuth,
 )
 
 API_BASE_URL = "https://eapi.charge.space"
+API_VERSION = "v4"
 
 
 class ChargeAmpsExternalClient(ChargeAmpsClient):
@@ -45,7 +47,7 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
     async def _ensure_token(self):
         if self._token_expire < time.time():
             response = await self._session.post(
-                urljoin(self._base_url, "/api/v3/auth/login"),
+                urljoin(self._base_url, f"/api/{API_VERSION}/auth/login"),
                 ssl=self._ssl,
                 headers={"apiKey": self._api_key},
                 json={"email": self._email, "password": self._password},
@@ -78,7 +80,7 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
 
     async def get_chargepoints(self) -> List[ChargePoint]:
         """Get all owned chargepoints"""
-        request_uri = "/api/v3/chargepoints/owned"
+        request_uri = f"/api/{API_VERSION}/chargepoints/owned"
         response = await self._get(request_uri)
         res = []
         for chargepoint in await response.json():
@@ -97,7 +99,9 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
             query_params["startTime"] = start_time.isoformat()
         if end_time:
             query_params["endTime"] = end_time.isoformat()
-        request_uri = f"/api/v3/chargepoints/{charge_point_id}/chargingsessions"
+        request_uri = (
+            f"/api/{API_VERSION}/chargepoints/{charge_point_id}/chargingsessions"
+        )
         response = await self._get(request_uri, params=query_params)
         res = []
         for session in await response.json():
@@ -108,15 +112,13 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
         self, charge_point_id: str, session: int
     ) -> ChargingSession:
         """Get charging session"""
-        request_uri = (
-            f"/api/v3/chargepoints/{charge_point_id}/chargingsessions/{session}"
-        )
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/chargingsessions/{session}"
         response = await self._get(request_uri)
         return ChargingSession.from_dict(await response.json())
 
     async def get_chargepoint_status(self, charge_point_id: str) -> ChargePointStatus:
         """Get charge point status"""
-        request_uri = f"/api/v3/chargepoints/{charge_point_id}/status"
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/status"
         response = await self._get(request_uri)
         return ChargePointStatus.from_dict(await response.json())
 
@@ -124,7 +126,7 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
         self, charge_point_id: str
     ) -> ChargePointSettings:
         """Get chargepoint settings"""
-        request_uri = f"/api/v3/chargepoints/{charge_point_id}/settings"
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/settings"
         response = await self._get(request_uri)
         return ChargePointSettings.from_dict(await response.json())
 
@@ -132,16 +134,14 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
         """Set chargepoint settings"""
         payload = settings.to_dict()
         charge_point_id = settings.id
-        request_uri = f"/api/v3/chargepoints/{charge_point_id}/settings"
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/settings"
         await self._put(request_uri, json=payload)
 
     async def get_chargepoint_connector_settings(
         self, charge_point_id: str, connector_id: int
     ) -> ChargePointConnectorSettings:
         """Get all owned chargepoints"""
-        request_uri = (
-            f"/api/v3/chargepoints/{charge_point_id}/connectors/{connector_id}/settings"
-        )
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/connectors/{connector_id}/settings"
         response = await self._get(request_uri)
         return ChargePointConnectorSettings.from_dict(await response.json())
 
@@ -152,7 +152,18 @@ class ChargeAmpsExternalClient(ChargeAmpsClient):
         payload = settings.to_dict()
         charge_point_id = settings.charge_point_id
         connector_id = settings.connector_id
-        request_uri = (
-            f"/api/v3/chargepoints/{charge_point_id}/connectors/{connector_id}/settings"
-        )
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/connectors/{connector_id}/settings"
         await self._put(request_uri, json=payload)
+
+    async def remote_start(
+        self, charge_point_id: str, connector_id: int, start_auth: StartAuth
+    ) -> None:
+        """Remote start chargepoint"""
+        payload = start_auth.to_dict()
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/connectors/{connector_id}/remotestart"
+        await self._put(request_uri, json=payload)
+
+    async def remote_stop(self, charge_point_id: str, connector_id: int) -> None:
+        """Remote stop chargepoint"""
+        request_uri = f"/api/{API_VERSION}/chargepoints/{charge_point_id}/connectors/{connector_id}/remotestop"
+        await self._put(request_uri)
